pub struct DistCanvas {
pub width: Option<f64>,
pub height: Option<f64>,
pub units: Option<String>,
}Expand description
Diagram canvas metadata.
Fields
width: Option<f64>height: Option<f64>units: Option<String>Trait Implementations
Sourceimpl Clone for DistCanvas
impl Clone for DistCanvas
Sourcefn clone(&self) -> DistCanvas
fn clone(&self) -> DistCanvas
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DistCanvas
impl Debug for DistCanvas
Sourceimpl<'de> Deserialize<'de> for DistCanvas
impl<'de> Deserialize<'de> for DistCanvas
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DistCanvas
impl JsonSchema for DistCanvas
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DistCanvas
impl PartialEq for DistCanvas
Sourcefn eq(&self, other: &DistCanvas) -> bool
fn eq(&self, other: &DistCanvas) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for DistCanvas
impl Serialize for DistCanvas
impl StructuralPartialEq for DistCanvas